@@ -50,7 +50,7 @@ def _change_foreign_key_refs(env, model_name, record_ids, target_record_id,
                 query += sql.SQL(extra_where)
             logged_query(
                 env.cr, query, {
-                    'record_ids': record_ids,
+                    'record_ids': tuple(record_ids),
                     'target_record_id': target_record_id,
                 }, skip_no_result=True,
             )
@@ -69,7 +69,7 @@ def _change_foreign_key_refs(env, model_name, record_ids, target_record_id,
                     'target_column': AsIs(target_column),
                     'table': AsIs(table),
                     'column': AsIs(column),
-                    'record_ids': record_ids,
+                    'record_ids': tuple(record_ids),
                 },
             )
             for row in list(set([x[0] for x in env.cr.fetchall()])):
@@ -100,7 +100,7 @@ def _change_foreign_key_refs(env, model_name, record_ids, target_record_id,
                     {
                         'table': AsIs(table),
                         'column': AsIs(column),
-                        'record_ids': record_ids,
+                        'record_ids': tuple(record_ids),
                     }, skip_no_result=True,
                 )
         else:
@@ -280,7 +280,7 @@ def _change_translations_sql(env, model_name, record_ids, target_record_id,
         WHERE it.id = to_update.id""",
         {
             'target_record_id': target_record_id,
-            'record_ids': record_ids,
+            'record_ids': tuple(record_ids),
             'model_name': model_name,
         }, skip_no_result=True)
     logged_query(
@@ -402,6 +402,8 @@ def _adjust_merged_values_orm(env, model_name, record_ids, target_record_id,
     :param: field_spec: Dictionary with field names as keys and forced
       operation to perform as values. If a field is not present here, default
       operation will be performed.
+      Note: If you pass 'openupgrade_other_fields': 'preserve' in the dict,
+      the fields that are not specified in the dict will not be adjusted.
 
       Possible operations by field types:
 
@@ -460,6 +462,9 @@ def _adjust_merged_values_orm(env, model_name, record_ids, target_record_id,
     vals = {}
     o2m_changes = 0
     for field in fields:
+        if field_spec.get('openupgrade_other_fields', '') == 'preserve' \
+                and field.name not in field_spec:
+            continue
         if not field.store or field.compute or field.related:
             continue  # don't do anything on these cases
         op = field_spec.get(field.name, False)
@@ -500,6 +505,8 @@ def _adjust_merged_values_sql(env, model_name, record_ids, target_record_id,
     :param: field_spec: Dictionary with field names as keys and forced
       operation to perform as values. If a field is not present here, default
       operation will be performed.
+      Note: If you pass 'openupgrade_other_fields': 'preserve' in the dict,
+      the fields that are not specified in the dict will not be adjusted.
 
       Possible operations by field types same as _adjust_merged_values_orm.
     """
@@ -527,6 +534,9 @@ def _adjust_merged_values_sql(env, model_name, record_ids, target_record_id,
     new_vals = {}
     vals = {}
     for i, (column, column_type, field_type) in enumerate(dict_column_type):
+        if field_spec.get('openupgrade_other_fields', '') == 'preserve' \
+                and column not in field_spec:
+            continue
         op = field_spec.get(column, False)
         _list = list(lists[i])
         field_vals = apply_operations_by_field_type(
@@ -622,7 +632,7 @@ def _change_generic(env, model_name, record_ids, target_record_id,
             query_args = {
                 'model_name': model_name,
                 'target_record_id': target_record_id,
-                'record_ids': record_ids,
+                'record_ids': tuple(record_ids),
             }
             query = sql.SQL(
                 """UPDATE {table} SET {res_id_column} = %(target_record_id)s
